import logging


def ips_logger() -> logging.Logger:
    """
    Author        : Elinor Thorne
    Date          : 5 Jan 2018
    Purpose       : Sets up and returns database logger object
    Parameters    : None
    Returns       : Database logger object
    Requirements  : None
    Dependencies  : social_surveys.setup_logging
    """

    logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    return logging.getLogger()

log = ips_logger()




import os
import re
import yaml

from pkg_resources import resource_string


class Configuration:
    path_matcher = re.compile(r'\$\{([^}^{]+)\}')

    def __init__(self, package=None, yaml_file=None):
        yaml.add_implicit_resolver('!path', self.path_matcher, None, yaml.SafeLoader)
        yaml.add_constructor('!path', self._path_constructor, yaml.SafeLoader)
        if yaml_file is not None:
            yml = resource_string(package, yaml_file)
        else:
            yml = resource_string(__name__, 'config.yaml')
        self.cfg = yaml.safe_load(yml)

    def config(self):
        return self.cfg

    def _path_constructor(self, loader, node):
        value = node.value
        match = self.path_matcher.match(value)
        env_var = match.group()[2:-1]
        return os.environ.get(env_var)




#
# Set the version tag: git tag -a 0.1.9 -m "version 0.1.9"
# To build: python3 setup.py sdist bdist_wheel
# Push to PyPy: twine upload dist/*
#


import setuptools

setuptools.setup(setup_requires=['pbr'], pbr=True)
